@@ -268,7 +268,7 @@ class Background:
         plt.plot([bb0x,bb1x,bb1x,bb0x,bb0x],[bb0y,bb0y,bb1y,bb1y,bb0y],color=color,ls='-')
         plt.xlim(bb0x-border_x,bb1x+border_x)
         plt.ylim(bb0y-border_y,bb1y+border_y)
-        plt.title(tmp.data['ROOTNAME'],fontsize=fontsize) 
+        plt.title(self.data['ROOTNAME'],fontsize=fontsize) 
         plt.tight_layout()
         if save:
             string = '{0}_bbox2d.{1}'.format(savename_prefix,saveformat)
